/*
 * Copyright (C) 2012 by I.Kato @ BS21 Lab
 * DIPSW8x8 library for Arduino
 *    ver.1.00 (3/oct/2012)
 *
 * 対象     : 8 DIP SW シールド (BS21LAB-001)
 * 接続方法 : SPI 通信方式
 *
 * 製品名は 8 DIP SW ですが、Arduino の命名制約により、DIPSW8x8 としてます。
 * 詳細は http://www.bs21-lab.com/products/p001-8DIPSW/ を御覧下さい。
 *
 * This file is free software; you can redistribute it and/or modify it
 * under the terms of either the GNU General Public License version 2
 * or the GNU Lesser General Public License version 2.1,
 * both as published by the Free Software Foundation.
 */

#ifndef __DIPSW8x8_H__
#define __DIPSW8x8_H__

// DIPSW1～8 までの番号を定義
// readByte 関数の swNo には、これを使用してください。
#ifndef DIPSW8x8_SW1
#define DIPSW8x8_SW1  0
#define DIPSW8x8_SW2  1
#define DIPSW8x8_SW3  2
#define DIPSW8x8_SW4  3
#define DIPSW8x8_SW5  4
#define DIPSW8x8_SW6  5
#define DIPSW8x8_SW7  6
#define DIPSW8x8_SW8  7
#endif

// 8 DIPSW クラス宣言
class DIPSW8x8 {
public:
  DIPSW8x8(uint8_t slaveSelPin); // コンストラクタ：スレーブピン番号を指定
  ~DIPSW8x8(); // デストラクタ

public:
  void begin(void); // 初期化処理
  void end  (void); // 終了処理

  void setReadMode(void); // SPIのモードを、8 DIPSW シールド用にセットします。

  byte readByte(byte swNo); // 指定された DIPSW 番号の現在の値を読み取ります。

private:
  uint8_t _slaveSelPin; // コンストラクタで指定したスレーブピン番号を保持しておきます。
};

#endif // __DIPSW8x8_H__
