/*
  DIPSW8x8 Library - Show All Values of DIPSW8x8 to Char LCD

  本スケッチは "8 DIP SW シールド" の現在の値を、キャラLCD に表示するスケッチ例です。

  Circuit:
    pins 11(MOSI), 12(MISO), 13(SCK) for SPI communication in Arduino standard.
    pins 51(MOSI), 50(MISO), 52(SCK) for SPI communication in Arduino Mega.
    ICSP ピンからの SPI 接続もOK です。
    pin 10 for Slave Select for Your DIPSW8x8's shield.

  created 3/oct/2012 by I.Kato @ BS21 Lab

  This code is in the public domain.
*/

// キャラLCD ライブラリを include します。
#include <LiquidCrystal.h>

// DIPSW8x8 ライブラリよりも先に SPI ライブラリを include する必要があります。
#include <SPI.h>

// 続いて DIPSW8x8 ライブラリを include します。
#include <DIPSW8x8.h>


// 御使いの LCD のピン番号に合わせて、以下を修正してください。
LiquidCrystal lcd(2, 3, 4, 5, 6, 7);

// 御使用の 8 DIP SW シールドの SS ピン番号に合わせて、以下を修正してください。
DIPSW8x8 dipsw8x8(10); // DIPSW8x8 のインスタンスを作成します。


// 最初に１回だけ呼び出される
void setup()
{
  // LCD の初期化
  lcd.begin(16, 2);
  lcd.clear();
  lcd.setCursor(0, 0);
  lcd.print("8 DIP SW: AllVal"); // １行目にタイトル表示

  SPI.begin(); // 最初に SPI ライブラリを初期化させてください。
  lcd.setCursor(0, 1);
  lcd.print("SPI init.");

  dipsw8x8.begin(); // 続いて 8DIPSW ライブラリを初期化させます。
  dipsw8x8.setReadMode(); // 8DIPSW 用の SPI モードを設定します。
  lcd.setCursor(0, 1);
  lcd.print("dipsw8x8 init.");
}

// ループ関数
void loop()
{
  char str[8]; // テキスト変換用バッファ

  lcd.setCursor(0, 1); // カーソル位置

  int swNo;
  for (swNo = DIPSW8x8_SW1; swNo <= DIPSW8x8_SW8; swNo++) { // SW1～SW8 までをループさせます

    byte val = dipsw8x8.readByte(swNo); // 指定の DIPSW の現在の値を読み取ります。

    sprintf(str, "%02X", val); // 読み取った値をテキストに変換
    lcd.print(str); // 入力値を表示
  }

  delay(100); // 100ms待ち
}

