/*
  DIPSW8x8 Library - Show All Values of DIPSW8x8 to Serial monitor

  本スケッチは "8 DIP SW シールド" の現在の値を、シリアルモニターに転送するスケッチ例です。

  Circuit:
    pins 11(MOSI), 12(MISO), 13(SCK) for SPI communication in Arduino standard.
    pins 51(MOSI), 50(MISO), 52(SCK) for SPI communication in Arduino Mega.
    ICSP ピンからの SPI 接続もOK です。
    pin 10 for Slave Select for Your DIPSW8x8's shield.

  created 10/july/2012 by I.Kato @ BS21 Lab
  modified 3/oct/2012 by I.Kato @ BS21 Lab

  This code is in the public domain.
*/

// DIPSW8x8 ライブラリよりも先に SPI ライブラリを include する必要があります。
#include <SPI.h>

// 続いて DIPSW8x8 ライブラリを include します。
#include <DIPSW8x8.h>


// 御使用の 8 DIP SW シールドの SS ピン番号に合わせて、以下を修正してください。
DIPSW8x8 dipsw8x8(10); // DIPSW8x8 のインスタンスを作成します。


// 最初に１回だけ呼び出される
void setup()
{
  Serial.begin(9600); // 9600bps で不都合な場合は、適宜、変更してください。

  // Arduino Leonardo では、以下の待ちループが必要です。
  while (!Serial) {
    ; // wait for serial port to connect. Needed for Leonardo only
  }

  SPI.begin(); // 最初に SPI ライブラリを初期化させてください。
  Serial.println("SPI.begin() done.");

  dipsw8x8.begin(); // 続いて 8DIPSW ライブラリを初期化させます。
  dipsw8x8.setReadMode(); // 8DIPSW 用の SPI モードを設定します。
  Serial.println("dipsw8x8.begin() done.");

  Serial.println("Press any key."); // キー入力要求メッセージを表示

  while (!Serial.available()) { // シリアルモニターにキー入力があるまで待ちます。
    ;
  }

  int dummy = Serial.read(); // 空読みさせます。
}

// ループ関数
void loop()
{
  char str[8]; // テキスト変換用バッファ

  Serial.print(">> "); // プロンプトを表示

  int swNo;
  for (swNo = DIPSW8x8_SW1; swNo <= DIPSW8x8_SW8; swNo++) { // SW1～SW8 までをループさせます

    byte val = dipsw8x8.readByte(swNo); // 指定の DIPSW の現在の値を読み取ります。

    sprintf(str, "%02X", val); // 読み取った値をテキストに変換
    Serial.print(str); // シリアルモニターに転送

    if (swNo < DIPSW8x8_SW8) { // SW8 以外の時のみ
      Serial.print(" : "); // 分離記号(コロン)を表示
    }
  }
  // ループ終了

  Serial.print("\n"); // 改行させる

  delay(1000); // 1秒待機
}

